diff --git a/src/pages/config/pages/roleManage/index.vue b/src/pages/config/pages/roleManage/index.vue
index 1ee302ba5..02201fc96 100644
--- a/src/pages/config/pages/roleManage/index.vue
+++ b/src/pages/config/pages/roleManage/index.vue
@@ -171,7 +171,7 @@
:data="treeData3"
:props="defaultProps3"
:default-checked-keys="nodeList2"
- default-expand-all
+ :default-expanded-keys="defaultExpandedKeys"
highlight-current
:expand-on-click-node="false"
:show-checkbox="true"
@@ -202,7 +202,7 @@
:data="treeData4"
:props="defaultProps3"
:default-checked-keys="nodeList4"
- default-expand-all
+ :default-expanded-keys="defaultExpandedKeys"
highlight-current
:expand-on-click-node="false"
:show-checkbox="true"
@@ -468,7 +468,8 @@ export default {
children: 'children',
label: 'menuName'
},
- nodeList: []
+ nodeList: [],
+ defaultExpandedKeys:[]//默认展开的key
}
},
methods: {
@@ -685,6 +686,8 @@ export default {
this.treeData4 = this.sortByKey(list1,"displaySeq")
}
+ // 默认展开的key
+ this.defaultExpandedKeys = list1.map(item=>item.id)
},
sortByKey(ary, key) {
diff --git a/src/pages/details/otherStandardDetails/index.vue b/src/pages/details/otherStandardDetails/index.vue
index 5afcf5de7..8cf108884 100644
--- a/src/pages/details/otherStandardDetails/index.vue
+++ b/src/pages/details/otherStandardDetails/index.vue
@@ -2161,7 +2161,10 @@ export default {
child6Func(child6) {
const list = []
if (child6 && child6.length > 1) {
- list.push(child6[0])
+ for(let i = 0 ; i < child6.length ; i++){
+ list.push(child6[i])
+ }
+ // list.push(child6[0])
return list
}
return child6
diff --git a/src/pages/regulatoryRepository/domesticStandardsAndRegulations/index.vue b/src/pages/regulatoryRepository/domesticStandardsAndRegulations/index.vue
index f1f5dc88c..4f2ea4784 100644
--- a/src/pages/regulatoryRepository/domesticStandardsAndRegulations/index.vue
+++ b/src/pages/regulatoryRepository/domesticStandardsAndRegulations/index.vue
@@ -756,6 +756,7 @@
:disabled="formdisableflag"
:show-modify-name="true"
@fileSuccess="fileSuccess"
+ :limit="['FBGBJBD','FBGYWBD','XDB','KWJ','ZBJBD'].some(item => item===field.attrField) ? 20 : 8"
>
@@ -3732,6 +3733,7 @@ export default {
})
this.dynamicFormField = displayLocation
this.loading = false
+ console.log(this.dynamicFormField)
})
})
})
diff --git a/src/pages/regulatoryRepository/enterpriseStandardDatabase/components/EnterpriseStandardDatabase.vue b/src/pages/regulatoryRepository/enterpriseStandardDatabase/components/EnterpriseStandardDatabase.vue
index f57926f37..725d1a540 100644
--- a/src/pages/regulatoryRepository/enterpriseStandardDatabase/components/EnterpriseStandardDatabase.vue
+++ b/src/pages/regulatoryRepository/enterpriseStandardDatabase/components/EnterpriseStandardDatabase.vue
@@ -854,6 +854,7 @@
v-model="sarBussionessStandEO[field.attrField]"
:disabled="formdisableflag"
:show-modify-name="true"
+ :limit="['FBGBJBD','FBGYWBD','XDB','KWJ','ZBJBD'].some(item => item===field.attrField) ? 20 : 8"
>
@@ -3874,6 +3875,7 @@ export default {
})
this.dynamicFormField = displayLocation
this.loading = false
+ console.log(this.dynamicFormField)
})
this.sarBussionessStandEO = JSON.parse(JSON.stringify(item))
this.sarBussionessStandEO["XCSJBUSS"] = this.dateFormatter()
diff --git a/src/pages/regulatoryRepository/foreignStandardsAndRegulations/index.vue b/src/pages/regulatoryRepository/foreignStandardsAndRegulations/index.vue
index 4d5235c77..952c0d808 100644
--- a/src/pages/regulatoryRepository/foreignStandardsAndRegulations/index.vue
+++ b/src/pages/regulatoryRepository/foreignStandardsAndRegulations/index.vue
@@ -951,6 +951,7 @@
:disabled="formdisableflag"
:show-modify-name="true"
@fileSuccess="fileSuccess"
+ :limit="20"
>
@@ -960,6 +961,7 @@
:disabled="formdisableflag"
:show-modify-name="true"
@fileSuccess="fileSuccess"
+ :limit="20"
>
@@ -1207,6 +1209,7 @@
v-model="sarStandardsInfoEO[field.attrField]"
:disabled="formdisableflag"
@fileSuccess="fileSuccess"
+ :limit="['XDB','KWJ','ZBJBD'].some(item => item===field.attrField) ? 20 : 8"
>
@@ -3136,6 +3139,7 @@ export default {
})
this.dynamicFormField = displayLocation
this.loading = false
+ console.log(this.dynamicFormField)
})
})
})
diff --git a/src/sysConfig/index.js b/src/sysConfig/index.js
index 4b5e53eb3..1467ca0b7 100644
--- a/src/sysConfig/index.js
+++ b/src/sysConfig/index.js
@@ -5,26 +5,26 @@
*/
// 服务器地址
// const devIp = '39.98.140.126'
-// const devInterfacePORT = '10005'
-// const devIp = '192.168.10.6'
+// const devInterfacePORT = '4202'
+// const devIp = '192.168.1.42'
+// const devInterfacePORT = '9999'
+const devIp = '10.10.10.46'
+const devInterfacePORT = '4202'
+// const devIp = '10.0.3.11'
+// const devIp = 'localhost'
+// const devInterfacePORT = '10086'
// const devIp = '62.234.136.153'
// const devInterfacePORT = '8033'
-const devIp = '10.19.11.243'
-const devInterfacePORT = '4304'
// 配置 idm 认证
const ssoLogin = 'http://sso.foton.com.cn/oauth2.0/authorize?client_id=app_slrs&response_type=code&redirect_uri='
-
-const ssoLogout = 'http://sso.foton.com.cn/logout?service='
// 配置 前端服务
-const devWebUrl = 'https://srms.foton.com.cn/#/'
+const devWebUrl = 'http://62.234.136.153:8038/#/'
// webLoginType : idm (线上统一登录) 、 webLoginType: dev (测试环境登录)
-const webLoginType = 'idm'
+const webLoginType = 'dev'
// 配置onlyOffice 前端服务
-const onlyOfficeUrl = 'http://10.100.5.116:8088'
-
-// 配置 kkFileView 前端服务
-const kkFileViewUrl = 'https://srms.foton.com.cn/preview'
+// const onlyOfficeUrl = 'http://127.0.0.1:8080'
+const onlyOfficeUrl = 'http://10.10.10.46:8889'
// 云端端口号
const DEV_CLOUD_RES_INTERFACE_PORT = '7777'
@@ -48,10 +48,12 @@ const processPort = '17210'
*****************************************************************/
// 生产环境配置
-// const prodIp = '62.234.136.153'
-// const prodInterfacePORT = '8033'
-const prodIp = 'srms.foton.com.cn'
-const prodInterfacePORT = ''
+// const prodIp = '39.98.140.126'
+// const prodInterfacePORT = '4201'
+const prodIp = '10.10.10.46'
+const prodInterfacePORT = '4202'
+// const prodIp = 'slrs.foton.com.cn'
+// const prodInterfacePORT = ''
// 判断环境
const serverIP = process.env.NODE_ENV === 'production' ? prodIp : devIp
@@ -59,16 +61,14 @@ const interfacePORT = process.env.NODE_ENV === 'production' ? prodInterfacePORT
const CLOUD_RES_INTERFACE_PORT = process.env.NODE_ENV === 'production' ? DEV_CLOUD_RES_INTERFACE_PORT : DEV_CLOUD_RES_INTERFACE_PORT
module.exports = {
- baseUrl: 'https://' + serverIP + ':' + interfacePORT,
+ baseUrl: 'http://' + serverIP + ':' + interfacePORT,
webLoginType: webLoginType,
ssoLoginUrlDev: ssoLogin + devWebUrl,
- ssoLogoutUrlDev: ssoLogout + devWebUrl,
ssoLoginUrl: ssoLogin,
onlyOfficeUrl: onlyOfficeUrl,
- kkFileViewUrl: kkFileViewUrl,
devWebUrl: devWebUrl,
- serverUrl: 'https://' + serverIP, // 服务器IP地址
- interfaceUrl: 'https://' + serverIP + ':' + interfacePORT + '/api/', // 服务器端接口访问地址,
+ serverUrl: 'http://' + serverIP, // 服务器IP地址
+ interfaceUrl: 'http://' + serverIP + ':' + interfacePORT + '/api/', // 服务器端接口访问地址,
cloudResInterFaceUrl: 'http://' + serverIP + ':' + interfacePORT + '/busApi/', // 云端资源库服务器端接口访问地址,
simpleUploadPath: 'api/' + simpleFilePath, // 单文件上传地址
multipleUploadPath: 'api/' + multipleFilePath, // 多文件上传地址
@@ -78,4 +78,4 @@ module.exports = {
enterprise: enterprise, // GQ广汽 SJZX数据中心
theme: theme, // 主题
processInterfaceURL: `http://${serverIP}:${processPort}/bat-wkflow`
-}
+}
\ No newline at end of file